import setuptools
setuptools.setup(
    name= 'solacalcu' ,
    author= 'Asala Hussien' ,
    description= 'simple calc library' ,
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3"
    ]
)